/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "Greenwichski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Apia = new String[] {
               "Apiaski standardny \u010das",
               "",
               "Apiaski l\u011btni \u010das",
               "",
               "Apiaski \u010das",
               "",
            };
        final String[] Cook = new String[] {
               "standardny \u010das Cookowych kupow",
               "",
               "l\u011btni \u010das Cookowych kupow",
               "",
               "\u010das Cookowych kupow",
               "",
            };
        final String[] Cuba = new String[] {
               "kubaski standardny \u010das",
               "",
               "kubaski l\u011btni \u010das",
               "",
               "kubaski \u010das",
               "",
            };
        final String[] Fiji = new String[] {
               "fid\u017aiski standardny \u010das",
               "",
               "fid\u017aiski l\u011btni \u010das",
               "",
               "fid\u017aiski \u010das",
               "",
            };
        final String[] Gulf = new String[] {
               "\u010das Persiskeho golfa",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "Chowdski standardny \u010das",
               "",
               "Chowdski l\u011btni \u010das",
               "",
               "Chowdski \u010das",
               "",
            };
        final String[] Iran = new String[] {
               "iranski standardny \u010das",
               "",
               "iranski l\u011btni \u010das",
               "",
               "iranski \u010das",
               "",
            };
        final String[] Niue = new String[] {
               "niueski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "Omski standardny \u010das",
               "",
               "Omski l\u011btni \u010das",
               "",
               "Omski \u010das",
               "",
            };
        final String[] Peru = new String[] {
               "peruski standardny \u010das",
               "",
               "peruski l\u011btni \u010das",
               "",
               "peruski \u010das",
               "",
            };
        final String[] Truk = new String[] {
               "chuukski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "\u010das kupy Wake",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "chilski standardny \u010das",
               "",
               "chilski l\u011btni \u010das",
               "",
               "chilski \u010das",
               "",
            };
        final String[] China = new String[] {
               "chinski standardny \u010das",
               "",
               "chinski l\u011btni \u010das",
               "",
               "chinski \u010das",
               "",
            };
        final String[] Cocos = new String[] {
               "\u010das Kokosowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "Daviski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "indiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Japan = new String[] {
               "japanski standardny \u010das",
               "",
               "japanski l\u011btni \u010das",
               "",
               "japanski \u010das",
               "",
            };
        final String[] Korea = new String[] {
               "korejski standardny \u010das",
               "",
               "korejski l\u011btni \u010das",
               "",
               "korejski \u010das",
               "",
            };
        final String[] Nauru = new String[] {
               "nauruski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "nepalski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "palauski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "samoaski standardny \u010das",
               "",
               "samoaski l\u011btni \u010das",
               "",
               "samoaski \u010das",
               "",
            };
        final String[] Syowa = new String[] {
               "Syowaski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "tongaski standardny \u010das",
               "",
               "tongaski l\u011btni \u010das",
               "",
               "tongaski \u010das",
               "",
            };
        final String[] Yukon = new String[] {
               "Yukonowy \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Alaska = new String[] {
               "alaskaski standardny \u010das",
               "",
               "alaskaski l\u011btni \u010das",
               "",
               "alaskaski \u010das",
               "",
            };
        final String[] Amazon = new String[] {
               "Amaconaski standardny \u010das",
               "",
               "Amaconaski l\u011btni \u010das",
               "",
               "Amaconaski \u010das",
               "",
            };
        final String[] Azores = new String[] {
               "acorski standardny \u010das",
               "",
               "acorski l\u011btni \u010das",
               "",
               "acorski \u010das",
               "",
            };
        final String[] Bhutan = new String[] {
               "bhutanski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "bruneiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "standardny \u010das Jutrowneje kupy",
               "",
               "l\u011btni \u010das Jutrowneje kupy",
               "",
               "\u010das Jutrowneje kupy",
               "",
            };
        final String[] Guyana = new String[] {
               "guyanski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Israel = new String[] {
               "israelski standardny \u010das",
               "",
               "israelski l\u011btni \u010das",
               "",
               "israelski \u010das",
               "",
            };
        final String[] Kosrae = new String[] {
               "kosraeski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "Mawsonski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "Moskowski standardny \u010das",
               "",
               "Moskowski l\u011btni \u010das",
               "",
               "Moskowski \u010das",
               "",
            };
        final String[] Ponape = new String[] {
               "ponapeski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tahiti = new String[] {
               "tahitiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "Taipehski standardny \u010das",
               "",
               "Taipehski l\u011btni \u010das",
               "",
               "Taipehski \u010das",
               "",
            };
        final String[] Tuvalu = new String[] {
               "tuvaluski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "Wostokski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "\u010das kupow Wallis a Futuna",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "arabski standardny \u010das",
               "",
               "arabski l\u011btni \u010das",
               "",
               "arabski \u010das",
               "",
            };
        final String[] Armenia = new String[] {
               "armenski standardny \u010das",
               "",
               "armenski l\u011btni \u010das",
               "",
               "armenski \u010das",
               "",
            };
        final String[] Bolivia = new String[] {
               "boliwiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "chathamski standardny \u010das",
               "",
               "chathamski l\u011btni \u010das",
               "",
               "chathamski \u010das",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "koordinowany sw\u011btowy \u010das",
               "UTC",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "ekwadorski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "gambierski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "georgiski standardny \u010das",
               "",
               "georgiski l\u011btni \u010das",
               "",
               "georgiski \u010das",
               "",
            };
        final String[] Irkutsk = new String[] {
               "Irkutski standardny \u010das",
               "",
               "Irkutski l\u011btni \u010das",
               "",
               "Irkutski \u010das",
               "",
            };
        final String[] Magadan = new String[] {
               "Magadanski standardny \u010das",
               "",
               "Magadanski l\u011btni \u010das",
               "",
               "Magadanski \u010das",
               "",
            };
        final String[] Myanmar = new String[] {
               "myanmarski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "standardny \u010das kupy Norfolk",
               "",
               "l\u011btni \u010das kupy Norfolk",
               "",
               "\u010das kupy Norfolk",
               "",
            };
        final String[] Noronha = new String[] {
               "standardny \u010das kupow Fernando de Noronha",
               "",
               "l\u011btni \u010das kupow Fernando de Noronha",
               "",
               "\u010das kupow Fernando de Noronha",
               "",
            };
        final String[] Reunion = new String[] {
               "reunionski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "Rotheraski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "\u010das Salomonskich kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "tokelauski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "uruguayski standardny \u010das",
               "",
               "uruguayski l\u011btni \u010das",
               "",
               "uruguayski \u010das",
               "",
            };
        final String[] Vanuatu = new String[] {
               "vanuatuski standardny \u010das",
               "",
               "vanuatuski l\u011btni \u010das",
               "",
               "vanuatuski \u010das",
               "",
            };
        final String[] Yakutsk = new String[] {
               "Jakutski standardny \u010das",
               "",
               "Jakutski l\u011btni \u010das",
               "",
               "Jakutski \u010das",
               "",
            };
        final String[] Atlantic = new String[] {
               "atlantiski standardny \u010das",
               "",
               "atlantiski l\u011btni \u010das",
               "",
               "atlantiski \u010das",
               "",
            };
        final String[] Brasilia = new String[] {
               "Brasiliski standardny \u010das",
               "",
               "Brasiliski l\u011btni \u010das",
               "",
               "Brasiliski \u010das",
               "",
            };
        final String[] Chamorro = new String[] {
               "chamorroski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Colombia = new String[] {
               "kolumbiski standardny \u010das",
               "",
               "kolumbiski l\u011btni \u010das",
               "",
               "kolumbiski \u010das",
               "",
            };
        final String[] Falkland = new String[] {
               "falklandski standardny \u010das",
               "",
               "falklandski l\u011btni \u010das",
               "",
               "falklandski \u010das",
               "",
            };
        final String[] Malaysia = new String[] {
               "malajziski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "malediwski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "Ulan-Batorski standardny \u010das",
               "",
               "Ulan-Batorski l\u011btni \u010das",
               "",
               "Ulan-Batorski \u010das",
               "",
            };
        final String[] Pakistan = new String[] {
               "pakistanski standardny \u010das",
               "",
               "pakistanski l\u011btni \u010das",
               "",
               "pakistanski \u010das",
               "",
            };
        final String[] Paraguay = new String[] {
               "Paraguayski standardny \u010das",
               "",
               "Paraguayski l\u011btni \u010das",
               "",
               "Paraguayski \u010das",
               "",
            };
        final String[] Pitcairn = new String[] {
               "\u010das Pitcairnowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Sakhalin = new String[] {
               "sachalinski standardny \u010das",
               "",
               "sachalinski l\u011btni \u010das",
               "",
               "sachalinski \u010das",
               "",
            };
        final String[] Suriname = new String[] {
               "surinamski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "argentinski standardny \u010das",
               "",
               "argentinski l\u011btni \u010das",
               "",
               "argentinski \u010das",
               "",
            };
        final String[] Christmas = new String[] {
               "\u010das Hodowneje kupy",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "galapagoski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "Hongkongski standardny \u010das",
               "",
               "Hongkongski l\u011btni \u010das",
               "",
               "Hongkongski \u010das",
               "",
            };
        final String[] Indochina = new String[] {
               "indochinski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "kirgiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "standardny \u010das kupy Lord-Howe",
               "",
               "l\u011btni \u010das kupy Lord-Howe",
               "",
               "\u010das kupy Lord-Howe",
               "",
            };
        final String[] Marquesas = new String[] {
               "marquesaski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "mauritiuski standardny \u010das",
               "",
               "mauritiuski l\u011btni \u010das",
               "",
               "mauritiuski \u010das",
               "",
            };
        final String[] Singapore = new String[] {
               "Singapurski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "venezuelski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Volgograd = new String[] {
               "Wolgogradski standardny \u010das",
               "",
               "Wolgogradski l\u011btni \u010das",
               "",
               "Wolgogradski \u010das",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "azerbajd\u017aanski standardny \u010das",
               "",
               "azerbajd\u017aanski l\u011btni \u010das",
               "",
               "azerbajd\u017aanski \u010das",
               "",
            };
        final String[] Bangladesh = new String[] {
               "banglade\u0161ski standardny \u010das",
               "",
               "banglade\u0161ski l\u011btni \u010das",
               "",
               "banglade\u0161ski \u010das",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "kapverdski standardny \u010das",
               "",
               "kapverdski l\u011btni \u010das",
               "",
               "kapverdski \u010das",
               "",
            };
        final String[] East_Timor = new String[] {
               "wuchodnotimorski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "seychellski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "tad\u017aikski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "uzbekski standardny \u010das",
               "",
               "uzbekski l\u011btni \u010das",
               "",
               "uzbekski \u010das",
               "",
            };
        final String[] Afghanistan = new String[] {
               "afghanski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "Krasnojarski standardny \u010das",
               "",
               "Krasnojarski l\u011btni \u010das",
               "",
               "Krasnojarski \u010das",
               "",
            };
        final String[] New_Zealand = new String[] {
               "nowoseelandski standardny \u010das",
               "",
               "nowoseelandski l\u011btni \u010das",
               "",
               "nowoseelandski \u010das",
               "",
            };
        final String[] Novosibirsk = new String[] {
               "Nowosibirski standardny \u010das",
               "",
               "Nowosibirski l\u011btni \u010das",
               "",
               "Nowosibirski \u010das",
               "",
            };
        final String[] Philippines = new String[] {
               "filipinski standardny \u010das",
               "",
               "filipinski l\u011btni \u010das",
               "",
               "filipinski \u010das",
               "",
            };
        final String[] Vladivostok = new String[] {
               "Wladiwostokski standardny \u010das",
               "",
               "Wladiwostokski l\u011btni \u010das",
               "",
               "Wladiwostokski \u010das",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "indiskooceanski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "\u010das Linijowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "nowofundlandski standardny \u010das",
               "",
               "nowofundlandski l\u011btni \u010das",
               "",
               "nowofundlandski \u010das",
               "",
            };
        final String[] Turkmenistan = new String[] {
               "turkmenski standardny \u010das",
               "",
               "turkmenski l\u011btni \u010das",
               "",
               "turkmenski \u010das",
               "",
            };
        final String[] French_Guiana = new String[] {
               "francoskoguyanski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "nowokaledonski standardny \u010das",
               "",
               "nowokaledonski l\u011btni \u010das",
               "",
               "nowokaledonski \u010das",
               "",
            };
        final String[] South_Georgia = new String[] {
               "ju\u017enogeorgiski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "Jekaterinburgski standardny \u010das",
               "",
               "Jekaterinburgski l\u011btni \u010das",
               "",
               "Jekaterinburgski \u010das",
               "",
            };
        final String[] Africa_Central = new String[] {
               "centralnoafriski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Eastern = new String[] {
               "wuchodoafriski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Western = new String[] {
               "zapadoafriski standardny \u010das",
               "",
               "zapadoafriski l\u011btni \u010das",
               "",
               "zapadoafriski \u010das",
               "",
            };
        final String[] DumontDUrville = new String[] {
               "Dumont d\u00b4 Urvilleski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "srjed\u017aoeuropski standardny \u010das",
               "MEZ",
               "srjed\u017aoeuropski l\u011btni \u010das",
               "MESZ",
               "srjed\u017aoeuropski \u010das",
               "MEZ",
            };
        final String[] Europe_Eastern = new String[] {
               "wuchodoeuropski standardny \u010das",
               "OEZ",
               "wuchodoeuropski l\u011btni \u010das",
               "OESZ",
               "wuchodoeuropski \u010das",
               "OEZ",
            };
        final String[] Europe_Western = new String[] {
               "zapadoeuropski standardny \u010das",
               "WEZ",
               "zapadoeuropski l\u011btni \u010das",
               "WESZ",
               "zapadoeuropski \u010das",
               "WEZ",
            };
        final String[] Mexico_Pacific = new String[] {
               "mexiski pacifiski standardny \u010das",
               "",
               "mexiski pacifiski l\u011btni \u010das",
               "",
               "mexiski pacifiski \u010das",
               "",
            };
        final String[] Africa_Southern = new String[] {
               "ju\u017enoafriski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Central = new String[] {
               "sewjeroameriski centralny standardny \u010das",
               "",
               "sewjeroameriski centralny l\u011btni \u010das",
               "",
               "sewjeroameriski centralny \u010das",
               "",
            };
        final String[] America_Eastern = new String[] {
               "sewjeroameriski wuchodny standardny \u010das",
               "",
               "sewjeroameriski wuchodny l\u011btni \u010das",
               "",
               "sewjeroameriski wuchodny \u010das",
               "",
            };
        final String[] America_Pacific = new String[] {
               "sewjeroameriski pacifiski standardny \u010das",
               "",
               "sewjeroameriski pacifiski l\u011btni \u010das",
               "",
               "sewjeroameriski pacifiski \u010das",
               "",
            };
        final String[] French_Southern = new String[] {
               "\u010das Francoskeho ju\u017eneho a antarktiskeho teritorija",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "\u010das Gilbertowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "hawaiisko-aleutski standardny \u010das",
               "",
               "hawaiisko-aleutski l\u011btni \u010das",
               "",
               "hawaiisko-aleutski \u010das",
               "",
            };
        final String[] Phoenix_Islands = new String[] {
               "\u010das Phoenixowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "standardny \u010das kupow St. Pierre a Miquelon",
               "",
               "l\u011btni \u010das kupow St. Pierre a Miquelon",
               "",
               "\u010das kupow St. Pierre a Miquelon",
               "",
            };
        final String[] America_Mountain = new String[] {
               "sewjeroameriski h\u00f3rski standardny \u010das",
               "",
               "sewjeroameriski h\u00f3rski l\u011btni \u010das",
               "",
               "sewjeroameriski h\u00f3rski \u010das",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "\u010das Marshallowych kupow",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "mexiski sewjerozapadny standardny \u010das",
               "",
               "mexiski sewjerozapadny l\u011btni \u010das",
               "",
               "mexiski sewjerozapadny \u010das",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "papua-nowoginejski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "srjed\u017aoawstralski standardny \u010das",
               "",
               "srjed\u017aoawstralski l\u011btni \u010das",
               "",
               "srjed\u017aoawstralski \u010das",
               "",
            };
        final String[] Australia_Eastern = new String[] {
               "wuchodoawstralski standardny \u010das",
               "",
               "wuchodoawstralski l\u011btni \u010das",
               "",
               "wuchodoawstralski \u010das",
               "",
            };
        final String[] Australia_Western = new String[] {
               "zapadoawstralski standardny \u010das",
               "",
               "zapadoawstralski l\u011btni \u010das",
               "",
               "zapadoawstralski \u010das",
               "",
            };
        final String[] Greenland_Eastern = new String[] {
               "wuchodogr\u00f6nlandski standardny \u010das",
               "",
               "wuchodogr\u00f6nlandski l\u011btni \u010das",
               "",
               "wuchodogr\u00f6nlandski \u010das",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "zapadogr\u00f6nlandski standardny \u010das",
               "",
               "zapadogr\u00f6nlandski l\u011btni \u010das",
               "",
               "zapadogr\u00f6nlandski \u010das",
               "",
            };
        final String[] Indonesia_Central = new String[] {
               "srjed\u017aoindoneski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Eastern = new String[] {
               "wuchodoindoneski",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Western = new String[] {
               "zapadoindoneski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "wuchodnokazachski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "zapadnokazachski \u010das",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "srjed\u017aozapadny awstralski standardny \u010das",
               "",
               "sjed\u017aozapadny awstralski l\u011btni \u010das",
               "",
               "srjed\u017aozapadny awstralski \u010das",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "JST", Japan },
            { "MIT", Apia },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "Etc/UTC", ETC_UTC },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Amman", Europe_Eastern },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Truk },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Apia", Apia },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Damascus", Europe_Eastern },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Sakhalin", Sakhalin },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Ust-Nera", Vladivostok },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "Greenwichski \u010das",
                    "",
                    "Irski l\u011btni \u010das",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Jersey", GMT },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "Greenwichski \u010das",
                    "",
                    "Britiski l\u011btni \u010das",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Dawson", Yukon },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "Greenwichski \u010das",
                    "",
                    "Britiski l\u011btni \u010das",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Pacific/Easter", Easter },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Ponape },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "Pacific/Wallis", Wallis },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Central },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/Perth", Australia_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey", GMT },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", Maldives },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Novosibirsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Volgograd },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Chihuahua", America_Central },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", Yukon },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Europe/Isle_of_Man", GMT },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "America/Scoresbysund", Greenland_Eastern },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "timezone.excity.Asia/Qatar", "Katar" },
            { "timezone.excity.Asia/Tokyo", "Tokio" },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Africa/Lome", "Lom\u00e9" },
            { "timezone.excity.Asia/Aqtobe", "Aktobe" },
            { "timezone.excity.Asia/Muscat", "Muskat" },
            { "timezone.excity.Asia/Riyadh", "Riad" },
            { "timezone.excity.Asia/Saigon", "Ho Chi Minhowe m\u011bsto" },
            { "timezone.excity.Asia/Taipei", "Taipeh" },
            { "timezone.excity.Asia/Tehran", "Teheran" },
            { "timezone.excity.Etc/Unknown", "njeznate" },
            { "timezone.excity.Europe/Kiev", "Kiew" },
            { "timezone.excity.Europe/Rome", "Rom" },
            { "timezone.excity.Africa/Accra", "Akkra" },
            { "timezone.excity.Africa/Cairo", "Kairo" },
            { "timezone.excity.Asia/Baghdad", "Bagdad" },
            { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
            { "timezone.excity.Asia/Karachi", "Kara\u010di" },
            { "timezone.excity.Asia/Nicosia", "Nikosia" },
            { "timezone.excity.Asia/Rangoon", "Rangun" },
            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
            { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
            { "timezone.excity.Asia/Yerevan", "Jerjewan" },
            { "timezone.excity.Pacific/Fiji", "Fid\u017ai" },
            { "timezone.excity.Asia/Calcutta", "Kalkutta" },
            { "timezone.excity.Asia/Damascus", "Damaskus" },
            { "timezone.excity.Asia/Dushanbe", "Du\u0161anbe" },
            { "timezone.excity.Asia/Jayapura", "Port Numbay" },
            { "timezone.excity.Asia/Sakhalin", "Sachalin" },
            { "timezone.excity.Asia/Tashkent", "Ta\u0161kent" },
            { "timezone.excity.Europe/Athens", "Athen" },
            { "timezone.excity.Europe/Lisbon", "Lissabon" },
            { "timezone.excity.Europe/Moscow", "Moskwa" },
            { "timezone.excity.Europe/Prague", "Praha" },
            { "timezone.excity.Europe/Tirane", "Tirana" },
            { "timezone.excity.Europe/Vienna", "Wien" },
            { "timezone.excity.Europe/Warsaw", "War\u0161awa" },
            { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
            { "timezone.excity.Indian/Comoro", "Komory" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.Africa/Algiers", "Algier" },
            { "timezone.excity.Africa/Tripoli", "Tripolis" },
            { "timezone.excity.America/Bogota", "Bogot\u00e1" },
            { "timezone.excity.America/Cayman", "Kaimanske kupy" },
            { "timezone.excity.America/Havana", "Havanna" },
            { "timezone.excity.Asia/Hong_Kong", "Hongkong" },
            { "timezone.excity.Asia/Kamchatka", "Kam\u010datka" },
            { "timezone.excity.Asia/Pyongyang", "Pj\u00f6ngjang" },
            { "timezone.excity.Asia/Singapore", "Singapur" },
            { "timezone.excity.Europe/Vatican", "Vatikan" },
            { "timezone.excity.Europe/Vilnius", "Vilnius" },
            { "timezone.excity.Indian/Reunion", "R\u00e9union" },
            { "timezone.excity.Pacific/Easter", "Jutrowna kupa" },
            { "timezone.excity.Africa/Djibouti", "D\u017aibuti" },
            { "timezone.excity.Africa/El_Aaiun", "El Aai\u00fan" },
            { "timezone.excity.Africa/Khartoum", "Khartum" },
            { "timezone.excity.Africa/Sao_Tome", "S\u00e3o Tom\u00e9" },
            { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
            { "timezone.excity.America/Jamaica", "Jamaika" },
            { "timezone.excity.Atlantic/Azores", "Acory" },
            { "timezone.excity.Atlantic/Canary", "Kanariske kupy" },
            { "timezone.excity.Atlantic/Faeroe", "F\u00e4r\u00f6ske kupy" },
            { "timezone.excity.Europe/Belgrade", "B\u011b\u0142ohr\u00f3d" },
            { "timezone.excity.Europe/Brussels", "Br\u00fcssel" },
            { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
            { "timezone.excity.Europe/Chisinau", "Ki\u0161injow" },
            { "timezone.excity.Europe/Uzhgorod", "U\u017egorod" },
            { "timezone.excity.Indian/Maldives", "Malediwy" },
            { "timezone.excity.Africa/Mogadishu", "Mogadi\u0161u" },
            { "timezone.excity.America/Asuncion", "Asunci\u00f3n" },
            { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
            { "timezone.excity.Asia/Novosibirsk", "Nowosibirsk" },
            { "timezone.excity.Asia/Vladivostok", "Wladiwostok" },
            { "timezone.excity.Atlantic/Bermuda", "Bermudy" },
            { "timezone.excity.Europe/Bucharest", "Bukarest" },
            { "timezone.excity.Europe/Volgograd", "Wolgograd" },
            { "timezone.excity.Indian/Christmas", "Hodowna kupa" },
            { "timezone.excity.Africa/Porto-Novo", "Porto Novo" },
            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
            { "timezone.excity.Antarctica/Vostok", "Antarktika/Wostok" },
            { "timezone.excity.Asia/Novokuznetsk", "Nowokuznjeck" },
            { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
            { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
            { "timezone.excity.Europe/Zaporozhye", "Zapori\u017e\u017eja" },
            { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
            { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
            { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
            { "timezone.excity.Atlantic/Reykjavik", "Reykjav\u00edk" },
            { "timezone.excity.America/El_Salvador", "El Salvador" },
            { "timezone.excity.America/Mexico_City", "Mexiko m\u011bsto" },
            { "timezone.excity.Atlantic/Cape_Verde", "Kap Verde" },
            { "timezone.excity.Africa/Dar_es_Salaam", "Daressalam" },
            { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
            { "timezone.excity.America/St_Barthelemy", "St.Barth\u00e9lemy" },
            { "timezone.excity.Atlantic/South_Georgia", "Ju\u017ena Georgiska" },
            { "timezone.excity.Antarctica/DumontDUrville", "Dumont D\u2019Urville" },
            { "timezone.excity.America/North_Dakota/Beulah", "Beulah, Sewjerna Dakota" },
            { "timezone.excity.America/North_Dakota/Center", "Center, Sewjerna Dakota" },
            { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Sewjerna Dakota" },
        };
        return data;
    }
}
